@@ -8,14 +8,16 @@ class Utils:
 
     def list_to_df(self, list_arr):
         return pd.DataFrame.from_records([s for s in list_arr])
-    
+
     def help(self):
-        print(f'=== {type(self).__name__} === \n')
-        print(f'.dict_to_df(dict_arr) => convert dict in df\n')
-        print(f'.list_to_df(list_arr) => convert list in df\n')
+        print(f"=== {type(self).__name__} === \n")
+        print(".dict_to_df(dict_arr) => convert dict in df\n")
+        print(".list_to_df(list_arr) => convert list in df\n")
+
 
 class Dotdict(dict):
     """dot.notation access to dictionary attributes"""
+
     __getattr__ = dict.get
     __setattr__ = dict.__setitem__
     __delattr__ = dict.__delitem__
